* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery)
  * Software Bill of Materials (SBOM)
